@@ -316,8 +316,8 @@ mi <- min(bm_vec[, -seq_len(t_idx)])
 ma <- max(bm_vec[, (t_idx+1):(ncol(bm_vec)-4)])
 
 ggplot(mbm_vec, aes(x = factor(FuncName, levels = Names_vec), y = time,
-                             color = factor(FuncName, levels = Names_vec),
-                             fill = factor(FuncName, levels = Names_vec))) +
+                    color = factor(FuncName, levels = Names_vec),
+                    fill = factor(FuncName, levels = Names_vec))) +
   geom_violin(trim = TRUE, alpha = 0.5) +
   scale_color_manual(values = Outline_vec, guide = FALSE) +
   scale_fill_manual(values = Color_vec, guide = FALSE) +
@@ -341,8 +341,9 @@ ggplot(mbm_vec, aes(x = factor(FuncName, levels = Names_vec), y = time,
                                    vjust = 0.5, hjust = 1),
         axis.text.y = element_text(size = 16),
         axis.title.x = element_text(size = 20,
-                                    margin = margin(10, 5, 5, 5)),
-        axis.title.y = element_text(size = 20),
+                                    margin = margin(10, 0, 0, 0)),
+        axis.title.y = element_text(size = 20,
+                                    margin = margin(0, 10, 0, 0)),
         legend.position = "none")
 
 ## ----bm-meq-prep, eval=TRUE---------------------------------------------------
@@ -380,26 +381,29 @@ ggplot(mbm_meq, aes(x = RTAA, y = time,
                fun.max = function(z) { quantile(z, 0.9) },
                geom = "ribbon", color = NA, alpha = 0.2) +
   stat_summary(fun = mean, geom = "line") +
-  scale_x_log10() +
+  scale_x_log10(breaks = c(0.001, 0.1, 10, 1000),
+                labels = as.character(c(0.001, 0.1, 10, 1000))) +
   scale_color_manual(values = Color_meq) +
   scale_fill_manual(values = Color_meq) +
   labs(subtitle = paste(
          "The darker shaded regions represent the 10% and 90% quantiles",
          "The lighter shaded regions represent the min and max times",
          sep = ";\n"),
-       x = bquote(frac(rt, a^2) ~ ", effective response time, " ~ log[10]),
+       x = bquote(frac(t, a^2) ~ ", effective response time, " ~ log[10]),
        y = "Time (microseconds)") +
   theme_bw() +
   theme(panel.grid.minor = element_blank(),
         panel.border = element_blank(),
         plot.subtitle = element_text(size = 16,
-                                     margin = margin(5, 5, 15, 5, "pt")),
+                                     margin = margin(0, 0, 15, 0)),
         axis.text.x = element_text(size = 16, angle = 90,
                                    vjust = 0.5, hjust = 1),
         axis.text.y = element_text(size = 16),
-        axis.title.x = element_text(size = 18),
-        axis.title.y = element_text(size = 18),
-        strip.text = element_text(size = 14),
+        axis.title.x = element_text(size = 20,
+                                    margin = margin(10, 0, 0, 0)),
+        axis.title.y = element_text(size = 20,
+                                    margin = margin(0, 10, 0, 0)),
+        strip.text = element_text(size = 16),
         strip.background = element_rect(fill = "white"),
         legend.position = "none") +
   facet_wrap(~ factor(FuncName, levels = Names_meq), scales = "free_y",
@@ -968,7 +972,7 @@ mi <- min(fit[fit[["Algorithm"]] != "rtdists", "BmTime"])
 ma <- max(fit[fit[["Algorithm"]] != "rtdists", "BmTime"])
 
 ggplot(fit_mbm, aes(x = factor(Algorithm, levels = Names),
-                             y = BmTime)) +
+                    y = BmTime)) +
   geom_violin(trim = TRUE, alpha = 0.5,
               aes(color = factor(Algorithm, levels = Names),
                   fill = factor(Algorithm, levels = Names))) +
@@ -1025,9 +1029,10 @@ ggplot(fit_mbm, aes(x = factor(Algorithm, levels = Names),
         axis.text.x = element_text(size = 16, angle = 90,
                                    vjust = 0.5, hjust = 1),
         axis.text.y = element_text(size = 16),
-        axis.title.x = element_text(size = 20),
+        axis.title.x = element_text(size = 20,
+                                    margin = margin(15, 0, 0, 0)),
         axis.title.y = element_text(size = 20,
-                                    margin = margin(5, 10, 5, 5, "pt")),
+                                    margin = margin(0, 10, 0, 0)),
         legend.position = "right",
         legend.box = "vertical",
         legend.direction = "vertical",
@@ -1096,9 +1101,10 @@ ggplot(fit_fev, aes(x = factor(Algorithm, levels = Names),
         axis.text.x = element_text(size = 16, angle = 90,
                                    vjust = 0.5, hjust = 1),
         axis.text.y = element_text(size = 16),
-        axis.title.x = element_text(size = 20),
+        axis.title.x = element_text(size = 20,
+                                    margin = margin(15, 0, 0, 0)),
         axis.title.y = element_text(size = 20,
-                                    margin = margin(5, 10, 5, 5, "pt")),
+                                    margin = margin(0, 10, 0, 0)),
         legend.position = "right",
         legend.box = "vertical",
         legend.direction = "vertical",
